.. _ref_videotools:

************
video.tools
************

This module regroups advanced, useful (and less useful) functions for editing videos, by alphabetical order.


Credits
--------
.. automodule:: moviepy.video.tools.credits
   :members:
   :show-inheritance:

Drawing
--------
.. automodule:: moviepy.video.tools.drawing
   :members:
   :show-inheritance:

Segmenting
----------
.. automodule:: moviepy.video.tools.segmenting
   :members:
   :show-inheritance:

Subtitles
----------
.. automodule:: moviepy.video.tools.subtitles
   :members:
   :show-inheritance:

Tracking
--------
.. automodule:: moviepy.video.tools.tracking
   :members:
   :show-inheritance:


